//
//  CCViewController.m
//  ComAndCon
//
//  Created by Felix Rohrer on 15.04.13.
//  Copyright (c) 2013 Felix Rohrer. All rights reserved.
//

#import "CCViewController.h"

@interface CCViewController ()

@end

@implementation CCViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
    
    self.pickerDummyStringArray = [NSArray arrayWithObjects:@"One", @"Two", @"Three", nil];
    self.pickerStringArray = self.pickerDummyStringArray;
    self.tmpXmlArray = [[NSMutableArray alloc] initWithCapacity:5];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (IBAction)dataSourceChanged:(UISegmentedControl*)sender {
    NSLog(@"dataSourceChanged: %d", [sender selectedSegmentIndex]);
    
        switch ([sender selectedSegmentIndex]) {
        case 0:
            // dummy
            self.pickerStringArray = self.pickerDummyStringArray;
            break;
        case 1:
            //xml
            self.pickerStringArray = [self getXMLData];
            break;
        case 2:
            //json
                self.pickerStringArray = [self getJSONData];
            break;
        default:
            break;
    }
    
    [self.pickerView reloadAllComponents];
    
    return;
}

- (IBAction)testOperationQueue:(id)sender {
    NSLog(@"testOperationQueue...");
    
    NSOperationQueue* queue = [[NSOperationQueue alloc] init];
    NSMutableArray* orderArray = [NSMutableArray arrayWithCapacity:3];
    
    NSBlockOperation* blockOp1 = [NSBlockOperation blockOperationWithBlock:^(void){ [orderArray addObject:@"1"]; } ];
    NSBlockOperation* blockOp2 = [NSBlockOperation blockOperationWithBlock:^(void){ [orderArray addObject:@"2"]; } ];
    NSBlockOperation* blockOp3 = [NSBlockOperation blockOperationWithBlock:^(void){ [orderArray addObject:@"3"]; } ];

    [blockOp1 addDependency:blockOp2];
    [blockOp1 addDependency:blockOp3];
    [blockOp2 addDependency:blockOp3];
    
    [queue addOperation:blockOp1];
    [queue addOperation:blockOp2];
    [queue addOperation:blockOp3];
    
    [queue waitUntilAllOperationsAreFinished];
    
    UIAlertView *info = [[UIAlertView alloc] initWithTitle:@"Block Operation Ordering"
                                                   message:[NSString stringWithFormat:@"The three operations where executed in the following order:\n%@.", [orderArray componentsJoinedByString:@", "]]
                                                  delegate:self
                                         cancelButtonTitle:@"OK"
                                         otherButtonTitles: nil];
    [info show];
    
    return;
}


- (NSString *)pickerView:(UIPickerView *)pickerView titleForRow:(NSInteger)row forComponent:(NSInteger)component {
    NSLog(@"titleForRow %d: %@", row, [self.pickerStringArray objectAtIndex:row]);
    return [self.pickerStringArray objectAtIndex:row];
}

- (NSInteger)numberOfComponentsInPickerView:(UIPickerView *)pickerView {
    NSLog(@"numberOfComponentsInPickerView: 1");
    return 1;
}

- (NSInteger)pickerView:(UIPickerView *)pickerView numberOfRowsInComponent:(NSInteger)component {
    NSLog(@"numberOfRowsInComponent: %d", self.pickerStringArray.count);
    return self.pickerStringArray.count;
}

- (NSArray*)getXMLData {
    NSLog(@"getXMLData...");
    [self.tmpXmlArray removeAllObjects];
    
    NSURL* url = [NSURL URLWithString:@"http://wherever.ch/hslu/iPhoneAdressData.xml"];
    NSXMLParser* parser = [[NSXMLParser alloc] initWithContentsOfURL:url];
    [parser setDelegate:self];
    [parser parse];
    
    return [NSArray arrayWithArray:self.tmpXmlArray];
}

- (void)parser:(NSXMLParser *)parser
didStartElement:(NSString *)elementName
  namespaceURI:(NSString *)namespaceURI
 qualifiedName:(NSString *)qName
    attributes:(NSDictionary *)attributeDict {
    if ([elementName isEqualToString:@"Entry"]) {
        NSLog(@"> %@, %@, %@", [attributeDict valueForKey:@"firstName"], [attributeDict valueForKey:@"lastName"], [attributeDict valueForKey:@"plz"]);
        [self.tmpXmlArray addObject:[NSString stringWithFormat:@"%@ %@", [attributeDict valueForKey:@"firstName"], [attributeDict valueForKey:@"lastName"]]];
    }
    
}

- (NSArray*)getJSONData {
    NSLog(@"getJSONData...");
    [self.tmpXmlArray removeAllObjects];
    
    NSError *error = nil;
    
    NSURL* url = [NSURL URLWithString:@"http://wherever.ch/hslu/iPhoneAdressData.json"];
    //NSData* data = [NSURLConnection sendSynchronousRequest:[NSURLRequest requestWithURL:url] returningResponse:nil error:nil];
    NSData* data = [NSData dataWithContentsOfURL:url options:NSDataReadingUncached error:&error];
    
    if (error) {
        UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"ERROR"
                                                       message:[NSString stringWithFormat:@"Error loading JSON-Data:\n%@", error.localizedDescription]
                                                      delegate:self
                                             cancelButtonTitle:@"OK"
                                             otherButtonTitles: nil];
        [alert show];
        return [NSArray arrayWithObjects:@"-", nil];
    }
    
    NSArray *jsonArr = [NSJSONSerialization JSONObjectWithData:data options:0 error:nil];
    NSDictionary* attributeDict;
    
    for (int i=0; i < [jsonArr count]; i++) {
        attributeDict = [jsonArr objectAtIndex:i];
        NSLog(@"> %@, %@, %@", [attributeDict valueForKey:@"firstName"], [attributeDict valueForKey:@"lastName"], [attributeDict valueForKey:@"plz"]);
        [self.tmpXmlArray addObject:[NSString stringWithFormat:@"%@ %@", [attributeDict valueForKey:@"firstName"], [attributeDict valueForKey:@"lastName"]]];
    }
     
    return [NSArray arrayWithArray:self.tmpXmlArray];
}


@end
